@@ -1,4 +1,4 @@
-# Copyright(c) 2007-2009 by Lorenzo Gil Sanchez <lorenzo.gil.sanchez@gmail.com>
+# Copyright(c) 2007-2010 by Lorenzo Gil Sanchez <lorenzo.gil.sanchez@gmail.com>
 #
 # This file is part of Chavier.
 #
@@ -67,6 +67,7 @@ class App(object):
                 rotate=float,
                 label=unicode,
                 interval=int,
+                showLines=bool,
                 ),
             y=dict(
                 hide=bool,
@@ -77,6 +78,7 @@ class App(object):
                 rotate=float,
                 label=unicode,
                 interval=int,
+                showLines=bool,
                 ),
             ),
         background=dict(
@@ -131,8 +133,10 @@ class App(object):
                 ),
             ),
         title=unicode,
+        titleColor=str,
         titleFont=str,
         titleFontSize=int,
+        encoding=str,
         )
 
     def __init__(self):
